%global momorel 2

Summary: Professional multitrack audio recording application
Name: ardour
Version: 2.8
Release: %{momorel}m%{?dist}
License: GPLv2+
URL: http://ardour.org/
Group: Applications/Multimedia
Source0: http://ardour.org/files/releases/%{name}-%{version}.tar.bz2
Source1: %{name}.desktop
# patches from Fedora
Patch10: %{name}-%{version}-SConstruct.patch
Patch11: %{name}-session.cc-no_stomp.patch
Patch12: %{name}-2.5-HOST_NOT_FOUND.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: alsa-lib-devel
BuildRequires: atk-devel
BuildRequires: aubio-devel
BuildRequires: boost-devel >= 1.37.0-4m
BuildRequires: cairo-devel
BuildRequires: cairomm-devel
BuildRequires: curl-devel
BuildRequires: cwiid-devel
BuildRequires: cyrus-sasl-devel
BuildRequires: doxygen
BuildRequires: e2fsprogs-devel
BuildRequires: expat-devel
BuildRequires: fftw3-devel
BuildRequires: flac-devel
BuildRequires: freetype-devel
BuildRequires: gail-devel
BuildRequires: gettext
BuildRequires: glib2-devel
BuildRequires: glitz-devel
BuildRequires: gtk2-devel
BuildRequires: gtkmm-devel
BuildRequires: jack-devel
BuildRequires: krb5-devel
BuildRequires: keyutils-libs-devel
BuildRequires: libX11-devel
BuildRequires: libXau-devel
BuildRequires: libXcomposite-devel
BuildRequires: libXcursor-devel
BuildRequires: libXdamage-devel
BuildRequires: libXdmcp-devel
BuildRequires: libXext-devel
BuildRequires: libXfixes-devel
BuildRequires: libXft-devel
BuildRequires: libXi-devel
BuildRequires: libXinerama-devel
BuildRequires: libXrandr-devel
BuildRequires: libXrender-devel
BuildRequires: libart_lgpl-devel
BuildRequires: libcurl-devel
BuildRequires: libgnomecanvas-devel
BuildRequires: libgnomecanvasmm-devel
BuildRequires: libidn-devel
BuildRequires: liblo-devel
BuildRequires: liblrdf-devel
BuildRequires: libogg-devel
BuildRequires: libpng-devel
BuildRequires: libsamplerate-devel
BuildRequires: libselinux-devel
BuildRequires: libsigc++-devel
BuildRequires: libssh2-devel
BuildRequires: libtool
BuildRequires: libxcb-devel
BuildRequires: libxml2-devel
BuildRequires: libxslt-devel
BuildRequires: openldap-devel
BuildRequires: openssl-devel
BuildRequires: pango-devel
BuildRequires: pixman-devel
BuildRequires: pkgconfig
BuildRequires: python
BuildRequires: raptor-devel
BuildRequires: scons >= 1.2.0
BuildRequires: zlib-devel

%description
Ardour is a multichannel hard disk recorder. It is capable of recording 24
or more channels of 32 bit audio at 48kHz. Ardour is intended to function
as a "professional" HDR system, replacing dedicated hardware solutions such
as the Mackie HDR, the Tascan 2424 and more traditional tape systems like
the Alesis ADAT series. It supports MIDI Machine Control, and so can be
controlled from any MMC controller, such as the Mackie Digital 8 Bus mixer
and many other modern digital mixers.

Ardour-KSI is a curses-based interface to Ardour.

You MUST have jackd running and an ALSA sound driver to use ardour.

%prep
%setup -q

# patches from Fedora
%patch10 -p1 -b .build
%patch11 -p0 -b .no_stomp
%patch12 -p0 -b .HOST_NOT_FOUND

%build
# <sigh> ardours SConstruct script is a mess when it comes to determining
# opt_flags, so we override the lot using the ARCH= and DIST_TARGET= options

TARGETCPU="none"

%ifarch %{ix86}
ARCH_FLAGS="-DARCH_X86 -DBUILD_SSE_OPTIMIZATIONS"
TARGETCPU="i386"
%endif
%ifarch x86_64
ARCH_FLAGS="-DARCH_X86 -DBUILD_SSE_OPTIMIZATIONS -DUSE_X86_64_ASM"
TARGETCPU="x86_64"
%endif
%ifarch ppc
TARGETCPU=powerpc
%endif
%ifarch ppc64
TARGETCPU=powerpc64
%endif

scons %{?_smp_mflags} \
	PREFIX=%{_prefix} \
	LIBDIR=%{_lib} \
	WIIMOTE=1 \
	FREESOUND=1 \
	DIST_TARGET="$TARGETCPU" \
	ARCH="%{optflags} $ARCH_FLAGS -ffast-math"

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
mkdir -p %{buildroot}
scons install DESTDIR=%{buildroot}

# install desktop file
mkdir -p %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/applications/

# install icons
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/{16x16,22x22,32x32,48x48}/apps
install -m 644 gtk2_ardour/icons/ardour_icon_16px.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
install -m 644 gtk2_ardour/icons/ardour_icon_22px.png %{buildroot}%{_datadir}/icons/hicolor/22x22/apps/%{name}.png
install -m 644 gtk2_ardour/icons/ardour_icon_32px.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -m 644 gtk2_ardour/icons/ardour_icon_48px.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
mkdir -p %{buildroot}%{_datadir}/pixmaps
ln -s ../icons/hicolor/48x48/apps/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

# install the man pages
install -dm 755 %{buildroot}%{_mandir}/man1
install -p -m 0644 ardour.1 %{buildroot}%{_mandir}/man1/
for lang in es fr ru ; do
  install -dm 755 %{buildroot}%{_mandir}/${lang}/man1
  install -p -m 0644 ardour.1.${lang} %{buildroot}%{_mandir}/${lang}/man1/
done

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING README
%dir %{_sysconfdir}/ardour2
%config(noreplace) %{_sysconfdir}/ardour2/SAE-de-keypad.bindings
%config(noreplace) %{_sysconfdir}/ardour2/SAE-de-nokeypad.bindings
%config(noreplace) %{_sysconfdir}/ardour2/SAE-us-keypad.bindings
%config(noreplace) %{_sysconfdir}/ardour2/SAE-us-nokeypad.bindings
%config(noreplace) %{_sysconfdir}/ardour2/ardour-sae.menus
%config(noreplace) %{_sysconfdir}/ardour2/ardour.menus
%config(noreplace) %{_sysconfdir}/ardour2/ardour2_ui_dark.rc
%config(noreplace) %{_sysconfdir}/ardour2/ardour2_ui_dark_sae.rc
%config(noreplace) %{_sysconfdir}/ardour2/ardour2_ui_default.conf
%config(noreplace) %{_sysconfdir}/ardour2/ardour2_ui_light.rc
%config(noreplace) %{_sysconfdir}/ardour2/ardour2_ui_light_sae.rc
%config(noreplace) %{_sysconfdir}/ardour2/ardour_system.rc
%config(noreplace) %{_sysconfdir}/ardour2/ergonomic-us.bindings
%config(noreplace) %{_sysconfdir}/ardour2/mnemonic-us.bindings
%{_bindir}/ardour2
%{_libdir}/ardour2
%{_datadir}/applications/ardour.desktop
%{_datadir}/ardour2
%{_datadir}/icons/hicolor/*/apps/ardour.png
%{_datadir}/locale/*/LC_MESSAGES/*.mo
%{_mandir}/man1/ardour.1*
%{_mandir}/*/man1/ardour.1*
%{_datadir}/pixmaps/ardour.png

%changelog
* Sun Apr 12 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.8-2m)
- No NoSource

* Sun Mar 29 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.8-1m)
- version 2.8
- update SConstruct.patch
- remove gcc44.patch

* Sat Jan 24 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.7.1-6m)
- apply gcc44 patch

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.7.1-5m)
- rebuild against rpm-4.6

* Fri Jan  2 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.7.1-4m)
- set WIIMOTE=1
- BuildRequires: cwiid-devel

* Fri Jan  2 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.7.1-3m)
- BuildRequires: scons >= 1.2.0
- drop Patch0 for fuzz=0, already merged upstream
- License: GPLv2+

* Wed Dec 31 2008 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (2.7.1-2m)
- rebuild against python-2.6.1-1m and scons-1.0.1-2m

* Sun Dec  7 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.7.1-1m)
- version 2.7.1

* Wed Nov 26 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.7-1m)
- version 2.7
- re-import SConstruct.patch from Fedora

* Mon Oct 27 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.6.1-1m)
- version 2.6.1
- re-import SConstruct.patch and import HOST_NOT_FOUND.patch from Fedora
- remove merged flac-1.2.1.patch

* Sun Jul 13 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.5-1m)
- version 2.5
- use internal libraries again (hold BR for future version)
- use external scons again
- update gcc43.patch
- remove session.cc-_total_free_4k_blocks.patch

* Tue Jun  3 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (2.4.1-3m)
- rebuild against openssl-0.9.8h-1m

* Sat Apr 26 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.4.1-2m)
- use scons-local-0.97 for the moment

* Mon Apr 14 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.4.1-1m)
- replace gcc43.patch to Fedora's patch
- use external libraries

* Mon Apr  7 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.4-3m)
- import, modify and mixup gcc43.patch from opensuse, debian and fedora
- suse's ardour
 +-* Mon Nov 19 2007 tiwai@suse.de
 +- fix build with gcc 4.3
- debian's audacity
 +- Bug#455635: Log for failed build of audacity_1.3.4-1 (dist=unstable4)
- fedora's rubberband
 +* Sun Mar 30 2008 Michel Salim <michel.sylvan@gmail.com> - 1.0.1-1
 +- Initial package
- my flavor
 +- gtk2_ardour/fft_result.cc
 +- libs/glibmm2/glibmm/propertyproxy_base.cc
 +- libs/gtkmm2/gtk/gtkmm/scale.cc
 +- libs/gtkmm2/gtk/gtkmm/targetentry.cc

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.4-2m)
- rebuild against gcc43

* Tue Apr  1 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.4-1m)
- version 2.4
- import building style and 3 patches from Fedora

* Fri Feb  8 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.3.1-1m)
- version 2.3.1

* Mon Jan 21 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.2-1m)
- version 2.2
- License: GPLv2

* Tue Oct  2 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.1-1m)
- version 2.1
- remove merged gtk212.patch

* Sun Sep 23 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.0.5-2m)
- fix build on new gtk

* Wed Aug 15 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.0.5-1m)
- version 2.0.5

* Wed Aug  1 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.0.4-1m)
- version 2.0.4
- enable optflags
- enable parallel build
- import and modify ardour-no-sse.patch from Fedora
 +* Sat Jan 06 2007 Anthony Green <green@redhat.com> 0.99.3-8
 +- Add ardour-no-sse.patch to disable use of build-system dependent 
 +  hardware features (SSE, MMX, etc).
- remove merged powermate_installdir.patch

* Thu Jul  5 2007 Masanobu Sato <satoshiga@momonga-linux.org>
- (2.0.3-2m)
- add powermate installdir patch for lib64

* Wed Jul  4 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.0.3-1m)
- version 2.0.3

* Tue May 15 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.0.2-1m)
- version 2.0.2

* Wed May  2 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.0-1m)
- initial package for Momonga Linux
- Summary and %%description are imported from cooker
